**********************
``matplotlib.testing``
**********************


:mod:`matplotlib.testing`
=========================

.. automodule:: matplotlib.testing
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`matplotlib.testing.compare`
=================================

.. automodule:: matplotlib.testing.compare
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`matplotlib.testing.decorators`
====================================

.. automodule:: matplotlib.testing.decorators
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`matplotlib.testing.exceptions`
====================================

.. automodule:: matplotlib.testing.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
